AnimatedStatefulShellRoute class

Constructors

AnimatedStatefulShellRoute({required List<StatefulShellBranch> branches, required StatefulShellRouteBuilder builder, GoRouterRedirect? redirect, GlobalKey<NavigatorState>? parentNavigatorKey, StatefulShellRoutePageBuilder? pageBuilder, String? restorationScopeId, GlobalKey<StatefulNavigationShellState>? navigatorKey, Duration transitionDuration = const Duration(milliseconds: 300), Curve transitionCurve = Curves.easeInOut, required CustomRouteTransitionBuilder transitionBuilder})

Properties

branches → List<StatefulShellBranch>
Representations of the different stateful route branches that this shell route will manage.
finalinherited
builder → StatefulShellRouteBuilder?
The widget builder for a stateful shell route.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
The builder for the branch Navigator container.
finalinherited
pageBuilder → StatefulShellRoutePageBuilder?
The page builder for a stateful shell route.
finalinherited
parentNavigatorKey → GlobalKey<NavigatorState>?
An optional key specifying which Navigator to display this route's screen onto.
finalinherited
redirect → GoRouterRedirect?
An optional redirect function for this route.
finalinherited
restorationScopeId → String?
Restoration ID to save and restore the state of the navigator, including its history.
finalinherited
routes → List<RouteBase>
The list of child routes associated with this route.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transitionBuilder → CustomRouteTransitionBuilder
final
transitionCurve → Curve
final
transitionDuration → Duration
final

Methods

buildPage(BuildContext context, GoRouterState state, ShellRouteContext shellRouteContext) → Page?
Attempts to build the Page representing this shell route.
inherited
buildWidget(BuildContext context, GoRouterState state, ShellRouteContext shellRouteContext) → Widget?
Attempts to build the Widget representing this shell route.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
Returns the key for the Navigator that is to be used for the specified immediate sub-route of this shell route.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited